@@ -1,7 +1,7 @@
 package Carmel;
 use strict;
 use 5.010_001;
-use version; our $VERSION = version->declare('v0.1.12');
+use version; our $VERSION = version->declare('v0.1.13');
 
 1;
 __END__
@@ -35,6 +35,9 @@ Carmel - CPAN Artifact Repository Manager
   # Requires all your modules in cpanfile in one shot
   carmel exec perl -e 'Carmel::Runtime->require_all'
 
+  # Roll out the currently selected modules into ./local
+  carmel rollout
+
   # prints export PATH=... etc for shell scripting
   carmel export
 
