@@ -14,6 +14,7 @@ use Module::CPANfile;
 use Module::Metadata;
 use Path::Tiny ();
 use Pod::Usage ();
+use File::pushd;
 use Try::Tiny;
 
 use Class::Tiny {
@@ -213,7 +214,8 @@ sub dump_bootstrap {
     my @artifacts;
     $self->resolve(sub { push @artifacts, $_[0] });
 
-    my @inc  = map $_->sharedir_libs, @artifacts;
+    my @inc = map $_->nonempty_libs, @artifacts;
+    my @share = map $_->sharedir_libs, @artifacts;
     my @path = map $_->nonempty_paths, @artifacts;
 
     my %modules;
@@ -236,11 +238,12 @@ use Carmel::Runtime;
 
 # for carmel exec setup
 my %environment = (
-inc => @{[ quote \@inc ]},
-path => @{[ quote \@path ]},
-base => @{[ quote $file->parent->absolute ]},
-modules => @{[ quote \%modules ]},
-prereqs => @{[ quote $prereqs ]},
+inc      => @{[ quote \@inc ]},
+sharedir => @{[ quote \@share ]},
+path     => @{[ quote \@path ]},
+base     => @{[ quote $file->parent->absolute ]},
+modules  => @{[ quote \%modules ]},
+prereqs  => @{[ quote $prereqs ]},
 );
 
 Carmel::Runtime->environment(%environment);
@@ -326,7 +329,35 @@ sub cmd_tree {
         my($artifact, $depth) = @_;
         printf "%s%s (%s)\n", (" " x $depth), $artifact->package, $artifact->version || '0';
     });
+}
 
+sub cmd_rollout {
+    my $self = shift;
+
+    require ExtUtils::Install;
+    require ExtUtils::InstallPaths;
+
+    my @artifacts;
+    $self->resolve(sub { push @artifacts, $_[0] });
+
+    my $install_base = Path::Tiny->new("local")->absolute;
+    $install_base->remove_tree({ safe => 0 }) if $install_base->exists;
+
+    for my $artifact (@artifacts) {
+        my $dir = pushd $artifact->path;
+
+        my $paths = ExtUtils::InstallPaths->new(install_base => $install_base);
+        my %result;
+        ExtUtils::Install::install([
+            from_to => $paths->install_map,
+            verbose => 0,
+            dry_run => 0,
+            uninstall_shadows => 0,
+            skip => undef,
+            always_copy => 1,
+            result => \%result,
+        ]);
+    }
 }
 
 sub cmd_index {
